@@ -37,6 +37,7 @@ enum {
     opt_encrypt_to,
     opt_exit_on_status_write_error,
     opt_export,
+    opt_export_ssh,
     opt_fingerprint,
     opt_fixed_list_mode,
     opt_force_mdc,
@@ -140,6 +141,7 @@ static const int gpg_allowed_options[] = {
     opt_encrypt_to,
     opt_exit_on_status_write_error,
     opt_export,
+    opt_export_ssh,
     opt_fingerprint,
     opt_fixed_list_mode,
     opt_force_mdc,
@@ -231,6 +233,7 @@ static const struct option gpg_long_options[] = {
     {"encrypt-to", 1, 0, opt_encrypt_to},
     {"exit-on-status-write-error", 0, 0, opt_exit_on_status_write_error},
     {"export", 2, 0, opt_export},
+    {"export-ssh-key", 1, 0, opt_export_ssh},
     {"fingerprint", 0, 0, opt_fingerprint},
     {"fixed-list-mode", 0, 0, opt_fixed_list_mode},
     {"fixed-list-mode", 0, 0, opt_fixed_list_mode},
